"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Listr = require("listr");
const modify_manifest_1 = require("./modify-manifest");
const create_netsec_config_1 = require("./create-netsec-config");
const disable_certificate_pinning_1 = require("./disable-certificate-pinning");
const copy_certificate_file_1 = require("./copy-certificate-file");
function applyPatches(decodeDir, { debuggable = false, certificatePath, } = {}) {
    return new Listr([
        {
            title: 'Modifying app manifest',
            task: async (context) => {
                const result = await modify_manifest_1.default(path.join(decodeDir, 'AndroidManifest.xml'), debuggable);
                context.usesAppBundle = result.usesAppBundle;
            },
        },
        {
            title: 'Copying certificate file',
            skip: () => certificatePath ? false : '--certificate flag not specified.',
            task: () => copy_certificate_file_1.default(decodeDir, certificatePath),
        },
        {
            title: 'Replacing network security config',
            task: () => create_netsec_config_1.default(path.join(decodeDir, `res/xml/nsc_mitm.xml`), { certificatePath }),
        },
        {
            title: 'Disabling certificate pinning',
            task: (_, task) => disable_certificate_pinning_1.default(decodeDir, task),
        },
    ]);
}
exports.default = applyPatches;
