"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("../utils/fs");
const pathUtils = require("path");
/** Generates the XML contents of the Network Security File. */
const generateConfig = ({ certificatePath, }) => {
    const certificateBlock = certificatePath
        ? generateCertificateBlock(certificatePath)
        : '';
    return `<?xml version="1.0" encoding="utf-8"?>
  <!-- Intentionally lax Network Security Configuration (generated by apk-mitm) -->
  <network-security-config>
    <!-- Allow cleartext traffic -->
    <base-config cleartextTrafficPermitted="true">
      <trust-anchors>
        <!-- Allow user-added (proxy) certificates -->
        <certificates src="user" />${certificateBlock}
        <certificates src="system" />
      </trust-anchors>
    </base-config>
  </network-security-config>`;
};
/** Generates the XML block responsible for registering a custom certificate. */
const generateCertificateBlock = (path) => {
    const fileName = pathUtils.basename(path, '.pem');
    return `\n
        <!-- Allow specific certificate -->
        <certificates src="@raw/${fileName}" />\n`;
};
async function createNetworkSecurityConfig(path, { certificatePath } = {}) {
    await fs.mkdir(pathUtils.dirname(path), { recursive: true });
    const config = generateConfig({ certificatePath });
    await fs.writeFile(path, config, 'utf-8');
}
exports.default = createNetworkSecurityConfig;
